@@ -21,7 +21,7 @@ shinyServer(function(input, output, session) {
 
     ggiraph(code = print(p),
             hover_css = "fill:red;cursor:pointer;",
-            selection_type = "multiple",
+            selection_type = "single",
             selected_css = "fill:red;")
   })
 
