@@ -1,3 +1,4 @@
+library(ggplot2)
 library(ggiraph)
 library(maps)
 
@@ -17,7 +18,7 @@ shinyServer(function(input, output, session) {
   })
 
   output$plot <- renderggiraph({
-    ggiraph(code = print(gg_crime), selection_type = "multiple", zoom_max = 4,
+    ggiraph(code = print(gg_crime), width_svg = 6, height_svg = 8, selection_type = "multiple", zoom_max = 4,
             hover_css = "fill:#FF3333;stroke:black;cursor:pointer;",
             selected_css = "fill:#FF3333;stroke:black;")
   })
