@@ -2,7 +2,7 @@ library(ggiraph)
 shinyUI(fluidPage(
   fluidRow(
     column(
-      width=12,
+      width=6,offset = 3,
       textInput("selpoint", label = "Selected species"),
       ggiraphOutput("plot")
     )
